Welcome to Tiingo Python's documentation!
======================================

.. image:: https://img.shields.io/pypi/v/tiingo.svg?maxAge=600
       :target: https://pypi.python.org/pypi/tiingo

.. image:: https://img.shields.io/travis/hydrosquall/tiingo-python.svg?maxAge=600
       :target: https://travis-ci.org/hydrosquall/tiingo-python

.. image:: https://readthedocs.org/projects/tiingo-python/badge/?version=latest&maxAge=600
       :target: https://tiingo-python.readthedocs.io/en/latest/?badge=latest
       :alt: Documentation Status

.. image:: https://pyup.io/repos/github/hydrosquall/tiingo-python/shield.svg?maxAge=600
    :target: https://pyup.io/repos/github/hydrosquall/tiingo-python/
    :alt: Updates

.. image:: https://img.shields.io/codecov/c/github/hydrosquall/tiingo-python.svg?maxAge=600
    :target: https://codecov.io/gh/hydrosquall/tiingo-python
    :alt: Coverage


Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   modules
   contributing
   authors
   history


Tiingo is a financial data platform that makes high quality financial tools available to all. They have a RESTful and Real-Time Data API. Presently, the API includes support for the following endpoints:

* Stock Market Ticker Closing Prices + Metadata. Data includes full distribution details and is validated using a proprietary EOD Price Engine.
* (Coming Soon): Curated news from top financial news sources + curated blogs. Stories are tagged by Tiingo's algorithms.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
